Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/epubview/epub.py
diff options
context:
space:
mode:
authorLucian Branescu Mihaila <lucian.branescu@gmail.com>2010-10-12 21:19:24 (GMT)
committer Lucian Branescu Mihaila <lucian.branescu@gmail.com>2010-10-12 21:19:24 (GMT)
commitcd64b91c75f2fa0ed4626aa7bb257b25ed2675d1 (patch)
tree7a3bdf1f63374abe201fd8524205d27e43ac1344 /epubview/epub.py
parent16f7f33e80dfa02e2a308e19e48d1f6797b3e94a (diff)
Adapt to yet another change in the libevview API. SL#1900.HEADmaster
Diffstat (limited to 'epubview/epub.py')
-rw-r--r--epubview/epub.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/epubview/epub.py b/epubview/epub.py
index 71267aa..bf3f5c2 100644
--- a/epubview/epub.py
+++ b/epubview/epub.py
@@ -137,11 +137,11 @@ class _Epub(object):
'''
return self._tempdir
- def get_info(self):
+ def get_title(self):
'''
Returns a EpubInfo object for the open Epub file
'''
- return self._info
+ return self._info.title
def close(self):
'''
@@ -137,11 +137,11 @@ class _Epub(object):
'''
- Returns a EpubInfo object for the open Epub file
+ Returns a EpubInfo object title
'''